/**********************************************************
 ***  Header-Datei zur vorlufigen PCI1389S02-DLL       ***
 **********************************************************
 ***  Die Funktionen sollten sich nicht gegenber der   ***
 ***  endgltigen Version mit WIN9X-Treiber unter-      ***
 ***  scheiden.                                         ***
 **********************************************************
 ***       (c) 2002 by ERMA - Electronic GmbH           ***
 **********************************************************
 ***  Erstellt: 10.10.2002 Frank Jessen Dipl.Ing.(FH)   ***
 **********************************************************/
#ifndef _PCI1389S02_
#define _PCI1389S02_

/**********************************************************
 ***  Fehlermeldungen                                   ***
 **********************************************************/
#define PCI1389S02_ERR_OK            0
#define PCI1389S02_ERR_ALREADYOPEN   1
#define PCI1389S02_ERR_NOTOPEN       2
#define PCI1389S02_ERR_NOCARD        3
#define PCI1389S02_ERR_NOADDRESS     4
#define PCI1389S02_ERR_NOVALUE       5
#define PCI1389S02_ERR_WRONGMODE     6
#define PCI1389S02_ERR_VXDNOTFOUND   7
#define PCI1389S02_ERR_INTERNALERROR 8


/**********************************************************
 ***  Verwendete Typen                                  ***
 **********************************************************/
/*** Betriebsart ***/
struct _PCI1389S02_MODE
{
	UINT32  Cnt1_Mode;
	UINT32  Cnt2_Mode;
	unsigned short Ref_Mode;
	unsigned short Ref_Wert;
	unsigned short Io_Mode;
};

/*** Timeouts ***/
struct _PCI1389S02_TO
{
	UINT32 Cnt1;        // Wert Zhler 1 Timeout
	UINT32 Cnt2;        // Wert Zhler 2 Timeout
	UINT32 Ref;         // Wert Referenzzhler-Timeout
	unsigned char Cnt1En;      // Freigabe fr Zhler 1 Timeout
	unsigned char Cnt2En;      // Freigabe fr Zhler 2 Timeout
	unsigned char RefEn;       // Freigabe fr Referenzzhler Timeout
};

/*** Status ***/
struct _PCI1389S02_STAT
{
	unsigned short Cnt1;
	unsigned short Cnt2;
	unsigned short Ref;
};

/**********************************************************
 ***  Betriebsarten                                     ***
 **********************************************************/
#define PCI1389S02_INK1FACH    0x00000001		// Z1,Z2,Ref
#define PCI1389S02_INK2FACH    0x00000002		// Z1,Z2,Ref
#define PCI1389S02_INK4FACH    0x00000004		// Z1,Z2,Ref
#define PCI1389S02_EREIGNIS    0x00000008		// Z1,Z2,Ref
#define PCI1389S02_SWTRIG      0x00000010		// Z1,Z2
#define PCI1389S02_REFTRIG     0x00000020		// Z1,Z2
#define PCI1389S02_IOTRIG      0x00000040		// Z1,Z2
#define PCI1389S02_DIRTRIG     0x00010000   // Z1,Z2
#define PCI1389S02_INKREMENTAL 0x00000080		// Z1,Z2,Ref
#define PCI1389S02_TIMER       0x00000100   // Ref
#define PCI1389S02_TIMER5MHZ   0x00000200		// Z1,Z2
#define PCI1389S02_TIMER10MHZ  0x00000400		// Z1,Z2
#define PCI1389S02_RICHTUNG    0x00000800		// Z1,Z2,Ref
#define PCI1389S02_POLARITAET  0x00001000		// Z1,Z2,Ref
#define PCI1389S02_RESET       0x00002000		// Z1,Z2
#define PCI1389S02_SIOTRIG     0x00004000   // IO
#define PCI1389S02_FIOTRIG     0x00008000   // IO

/**********************************************************
 ***  Statusflags                                       ***
 **********************************************************/
#define PCI1389S02_CNTSTOP     0x0001		// Z1,Z2,Ref
#define PCI1389S02_CNTWAIT     0x0002		// Z1,Z2,Ref
#define PCI1389S02_CNTRUN      0x0004		// Z1,Z2,Ref
#define PCI1389S02_CNTTIMEOUT  0x0008		// Z1,Z2,Ref
#define PCI1389S02_CNTINERR    0x0010		// Z1,Z2,Ref
#define PCI1389S02_CNTFIFOOV   0x0020		// Z1,Z2

/**********************************************************
 ***  Flags fr Zhlerauswahl                           ***
 **********************************************************/
#define PCI1389S02_CNT1				 0x01			// Z1
#define PCI1389S02_CNT2        0x02			// Z2
#define PCI1389S02_REF         0x04     // Ref

/**********************************************************
 ***  Funktionen                                        ***
 **********************************************************/
#ifdef __cplusplus
    extern "C" {
#endif
/*** Allgemeine Funktionen ***/
__declspec (dllimport) char __stdcall PCI1389S02_InitDriver    (void);
__declspec (dllimport) char __stdcall PCI1389S02_DeInitDriver  (void);
__declspec (dllimport) char __stdcall PCI1389S02_GetCardCount  (unsigned char  *Anzahl);

/*** Konfigurationsfunktionen ***/
__declspec (dllimport) char __stdcall PCI1389S02_SetMode       (unsigned char Card, struct _PCI1389S02_MODE *Mode);
__declspec (dllimport) char __stdcall PCI1389S02_GetMode       (unsigned char Card, struct _PCI1389S02_MODE *Mode);
__declspec (dllimport) char __stdcall PCI1389S02_SetTimeOuts   (unsigned char Card, struct _PCI1389S02_TO   *TimeOuts);
__declspec (dllimport) char __stdcall PCI1389S02_GetTimeOuts   (unsigned char Card, struct _PCI1389S02_TO   *TimeOuts);

/*** Mefunktionen ***/
__declspec (dllimport) char __stdcall PCI1389S02_StartCounter  (unsigned char Card, unsigned char   Flags);
__declspec (dllimport) char __stdcall PCI1389S02_StopCounter   (unsigned char Card, unsigned char   Flags);
__declspec (dllimport) char __stdcall PCI1389S02_GetStatus     (unsigned char Card, struct _PCI1389S02_STAT *Status);
__declspec (dllimport) char __stdcall PCI1389S02_GetCNT1Values (unsigned char Card, INT32 (*buffer)[], UINT32 buffersize, UINT32 *n);
__declspec (dllimport) char __stdcall PCI1389S02_GetCNT2Values (unsigned char Card, INT32 (*buffer)[], UINT32 buffersize, UINT32 *n);
__declspec (dllimport) char __stdcall PCI1389S02_LatchCounter  (unsigned char Card, unsigned char Flags);
__declspec (dllimport) char __stdcall PCI1389S02_SetPorts      (unsigned char Card, unsigned char Flags);
__declspec (dllimport) char __stdcall PCI1389S02_GetPorts      (unsigned char Card, unsigned char *Flags);

/*** Fehlerfunktion ***/
__declspec (dllimport) int  __stdcall PCI1389S02_GetLastError  (unsigned char Card);

/*** Low-Level Funktionen ***/
/*** HINWEIS: Fr diese Funktionen gelten nicht ***/
/*** die oben definierten Werte, sondern der    ***/
/*** Bitplan aus der Programmieranleitung !!!   ***/
/*** Werden diese Funktionen benutzt, so werden ***/
/*** die obigen Funktionen ausgehebelt! Diese   ***/
/*** Funktionen greifen direkt auf die Hardware ***/
/*** zu. Die Softwarefifos knnen nicht mehr    ***/
/*** richtig funktionieren! Daher sollten       ***/
/*** entweder die obigen Funktionen oder die    ***/
/*** Low-Level-Funktionen benutzt werden. Das   ***/
/*** mischen der Funktionsgruppen fhrt zu      ***/
/*** Fehlern bei den Mefunktionen!             ***/
__declspec (dllimport) char __stdcall PCI1389S02_WriteCNT1     (unsigned char Card, UINT32   Wert);
__declspec (dllimport) char __stdcall PCI1389S02_ReadCNT1      (unsigned char Card, UINT32  *Wert);
__declspec (dllimport) char __stdcall PCI1389S02_WriteCNT2     (unsigned char Card, UINT32   Wert);
__declspec (dllimport) char __stdcall PCI1389S02_ReadCNT2      (unsigned char Card, UINT32  *Wert);
__declspec (dllimport) char __stdcall PCI1389S02_WriteMode     (unsigned char Card, UINT32   Mode);
__declspec (dllimport) char __stdcall PCI1389S02_ReadMode      (unsigned char Card, UINT32  *Mode);
__declspec (dllimport) char __stdcall PCI1389S02_ReadStatus    (unsigned char Card, UINT32  *Status);
__declspec (dllimport) char __stdcall PCI1389S02_Latch         (unsigned char Card, unsigned char   Flags);
__declspec (dllimport) char __stdcall PCI1389S02_WriteIntEn    (unsigned char Card, UINT32   IEN);
__declspec (dllimport) char __stdcall PCI1389S02_ReadIntEn     (unsigned char Card, UINT32  *IEN);
__declspec (dllimport) char __stdcall PCI1389S02_ReadIntStat   (unsigned char Card, UINT32  *IStat);
__declspec (dllimport) char __stdcall PCI1389S02_WriteRef      (unsigned char Card, unsigned short  Wert);
__declspec (dllimport) char __stdcall PCI1389S02_ReadRef       (unsigned char Card, unsigned short *Wert);
__declspec (dllimport) char __stdcall PCI1389S02_WriteIO       (unsigned char Card, unsigned char   Wert);
__declspec (dllimport) char __stdcall PCI1389S02_ReadIO        (unsigned char Card, unsigned char  *Wert);
//	}
#ifdef __cplusplus
    }
#endif
#endif
